@@ -336,12 +336,19 @@ class RummageFrame(gui.RummageFrame):
             self.m_settings_panel.SetDoubleBuffered(True)
         self.localize()
 
-        self.SetIcon(
-            data.get_image('rummage_large.png').GetIcon()
-        )
+        bundle = wx.IconBundle()
+        bundle.AddIcon(data.get_image('rummage_16.png').GetIcon())
+        bundle.AddIcon(data.get_image('rummage_32.png').GetIcon())
+        bundle.AddIcon(data.get_image('rummage_40.png').GetIcon())
+        bundle.AddIcon(data.get_image('rummage_128.png').GetIcon())
+        bundle.AddIcon(data.get_image('rummage_256.png').GetIcon())
+        bundle.AddIcon(data.get_image('rummage_512.png').GetIcon())
+        bundle.AddIcon(data.get_image('rummage_1024.png').GetIcon())
+
+        self.SetIcons(bundle)
 
         if util.platform() == "macos":
-            self.tbicon = TaskBarIcon(self, "Rummage", data.get_image('rummage_large.png').GetIcon())
+            self.tbicon = TaskBarIcon(self, "Rummage", data.get_image('rummage_512.png').GetIcon())
 
         self.encodings = util.get_encodings()
         self.last_pattern_search = ""
@@ -1996,13 +2003,20 @@ class RummageFrame(gui.RummageFrame):
         """Abort on escape."""
 
         # Do we actually need this cancel check?
+        canceled = True
         obj = self.FindFocus()
-        is_ac_combo = isinstance(obj, AutoCompleteCombo)
+        is_ac_combo = (
+            isinstance(obj, wx.ListCtrl) and
+            isinstance(obj.GetParent(), wx.PopupTransientWindow) and
+            isinstance(obj.GetParent().GetParent(), AutoCompleteCombo)
+        )
+        obj = obj.GetParent().GetParent()
         if is_ac_combo:
             canceled = obj.list.is_canceled()
-        if self.thread is not None and not self.kill and not canceled:
+            if not canceled and util.platform() == "windows":
+                obj.Dismiss()
+        if self.thread is not None and not self.kill and canceled:
             self.abort_search(self.m_replace_button.GetLabel() in (self.SEARCH_BTN_STOP, self.SEARCH_BTN_ABORT))
-
         event.Skip()
 
     def on_textctrl_selectall(self, event):
@@ -2057,11 +2071,8 @@ class RummageFrame(gui.RummageFrame):
             )
         dlg.Destroy()
         self.refresh_regex_options()
-        alt_row = Settings.get_alt_list_color()
-        self.m_result_file_list.EnableAlternateRowColours(enable=alt_row)
-        self.Refresh()
-        self.m_result_list.EnableAlternateRowColours(enable=alt_row)
-        self.Refresh()
+        self.m_result_file_list.update_colors()
+        self.m_result_list.update_colors()
 
     def on_chain_toggle(self, event):
         """Handle chain toggle event."""
